{
  pkgs',
  system,
  self,
  ...
}: let
  scriptBuildCoverReport = pkgs'.callPackage ./build-cover-report.nix {pkgs' = pkgs';};
  scriptRunTests = pkgs'.callPackage ./run-tests.nix {pkgs' = pkgs';};
  scriptRunExtendedTests = pkgs'.callPackage ./run-extended-tests.nix {pkgs' = pkgs';};
  scriptUpdateProject = pkgs'.callPackage ./update-project.nix {pkgs' = pkgs';};
  scriptUpdateChangelog = pkgs'.callPackage ./update-changelog.nix {pkgs' = pkgs';};

  taskfile = pkgs'.writeTextFile {
    name = "taskfile.yml";
    text = ''
      version: '3'

      tasks:
          default:
            cmds:
              - task --list
            silent: true

          run-tests:
            desc: Execute all tests.
            aliases:
              - a
            env:
              TEST_BY_TASK: true
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            cmds:
              - ${scriptRunTests}/bin/run-tests
            silent: true

          run-extended-tests:
            desc: Execute all tests including cover, bench and race tests.
            aliases:
              - s
            env:
              TEST_BY_TASK: true
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            cmds:
              - ${scriptRunExtendedTests}/bin/run-extended-tests
            silent: true

          build-cover-report:
            desc: Build coverage report.
            aliases:
              - d
            env:
              TEST_BY_TASK: true
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            cmds:
              - ${scriptBuildCoverReport}/bin/build-cover-report
            silent: true

          update-project:
            desc: Check code style, linting, and formatting.
            aliases:
              - e
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            cmds:
              - ${scriptUpdateProject}/bin/update-project
            silent: true

          git-commit:
            desc: Commit changes.
            aliases:
              - f
            cmds:
              - ${scriptUpdateProject}/bin/update-project
              - cd "{{.USER_WORKING_DIR}}" && cd $(${pkgs'.git}/bin/git rev-parse --show-toplevel) && nix run git+https://gitlab.schukai.com/schukai/entwicklung/nix-flakes#git-commit --no-write-lock-file
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"

          build-manual:
            aliases:
              - g
            desc: Build the manual
            cmds:
              - cd "{{.USER_WORKING_DIR}}" && cd $(${pkgs'.git}/bin/git rev-parse --show-toplevel) && ${pkgs'.nix}/bin/nix build .#manual --no-write-lock-file
            silent: true

          watch-doc:
            aliases:
              - l
            desc: Build and watch the documentation (http://localhost:3000)
            cmds:
              - cd "{{.USER_WORKING_DIR}}" && cd $(${pkgs'.git}/bin/git rev-parse --show-toplevel) && ${pkgs'.mdbook}/bin/mdbook serve documentation/manual/de
            silent: true

          update-changelog:
            aliases:
              - j
            desc: Update the changelog
            cmds:
              - ${scriptUpdateChangelog}/bin/update-changelog
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"

          tool-dbeaver:
            aliases:
              - k
              - dbeaver
            desc: Open DBeaver
            cmds:
              - cd "{{.USER_WORKING_DIR}}" && cd $(${pkgs'.git}/bin/git rev-parse --show-toplevel) && ${pkgs'.dbeaver-bin}/bin/dbeaver -data .temp/dbeaver -con "driver=mysql|host=localhost|port=3306|user=root|password=secret" 2>&1 > /dev/null
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"


    '';
  };
in
  pkgs'.writeShellScriptBin "task" ''
    ${pkgs'.go-task}/bin/task -t "${taskfile}" "$@"
  ''
